==> ismah-3.0.1%2B1.21.5%2Bfabric-sources.jar: com/github/razorplay01/ismah/common/mixin/PlayerRendererMixin.java <==
package com.github.razorplay01.ismah.common.mixin;

import com.github.razorplay01.ismah.client.util.LeashRenderer;
import com.github.razorplay01.ismah.client.util.LeashStateAccess;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import com.github.razorplay01.ismah.client.util.RenderUtil;
import net.minecraft.class_1007;
import net.minecraft.class_1306;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;

@Mixin(class_1007.class)
public class PlayerRendererMixin {
    //? if forge {
    /*//? if >= 1.19 && <= 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    //?}
*///?}
//? if fabric {
    //? if >= 1.19 && <= 1.21.1 {
    /*@Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    *///?}

    //? if >= 1.21.2 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(class_4587 poseStack, class_4597 buffer, int combinedLight, net.minecraft.class_2960 resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) class_310.method_1551().field_1724).getLeashState() && class_310.method_1551().field_1690.method_42552().method_41753() == class_1306.field_6183) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.class_572) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, class_1306.field_6183, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(class_4587 poseStack, class_4597 buffer, int combinedLight, net.minecraft.class_2960 resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) class_310.method_1551().field_1724).getLeashState() && class_310.method_1551().field_1690.method_42552().method_41753() == class_1306.field_6182) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.class_572) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, class_1306.field_6182, isSleeveVisible);
    }
    //?}
//?}
//? if neoforge {
    /*//? if 1.21 || 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.LEFT);
    }//?}

    //? if >= 1.21.2 {
    /^@Inject(method = "renderRightHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    ^///?}
*///?}
}

==> ismah-3.0.2%2B1.21%2Bfabric-sources.jar: com/github/razorplay01/ismah/common/mixin/PlayerRendererMixin.java <==
package com.github.razorplay01.ismah.common.mixin;

import com.github.razorplay01.ismah.client.util.LeashRenderer;
import com.github.razorplay01.ismah.client.util.LeashStateAccess;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import com.github.razorplay01.ismah.client.util.RenderUtil;
import net.minecraft.class_1007;
import net.minecraft.class_1306;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_591;
import net.minecraft.class_742;

@Mixin(class_1007.class)
public class PlayerRendererMixin {
    //? if forge {
    /*//? if >= 1.19 && <= 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    //?}
*///?}
//? if fabric {
    //? if >= 1.19 && <= 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(class_4587 poseStack, class_4597 buffer, int combinedLight, class_742 abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && class_310.method_1551().field_1690.method_42552().method_41753() == class_1306.field_6183) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (class_591) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((class_591) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, class_1306.field_6183);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(class_4587 poseStack, class_4597 buffer, int combinedLight, class_742 abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && class_310.method_1551().field_1690.method_42552().method_41753() == class_1306.field_6182) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (class_591) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((class_591) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, class_1306.field_6182);
    }
    //?}

    //? if >= 1.21.2 {
    /*@Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) Minecraft.getInstance().player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) Minecraft.getInstance().player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    *///?}
//?}
//? if neoforge {
    /*//? if 1.21 || 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.LEFT);
    }//?}

    //? if >= 1.21.2 {
    /^@Inject(method = "renderRightHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    ^///?}
*///?}
}
